#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InYT v82'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(chr(c) for c in [79, 117, 116, 49, 48, 67, 117, 114])
ACMCVD = 157
ACQFFT = 115
ADXLUB = "".join(
    chr(c)
    for c in [69, 120, 101, 114, 99, 105, 115, 101, 67, 111, 110, 116, 114, 111, 108]
)
AFIKJP = "".join(chr(c) for c in [70, 50, 49, 76, 105, 110, 101])
AHEOCT = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
AIIDNI = 66
AIVEMV = "".join(chr(c) for c in [68, 121, 110, 97, 115, 116, 121])
AJVDQL = "".join(chr(c) for c in [73, 110, 116, 111, 84, 117, 98])
AKQXPI = "".join(chr(c) for c in [72, 84, 82, 50])
AKSTSE = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
AMJMAO = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
AOAWBS = "".join(chr(c) for c in [76, 111])
AOESVZ = "".join(chr(c) for c in [65, 115, 115, 105, 103, 110, 86, 83, 80, 50])
AONPYY = "".join(chr(c) for c in [79, 117, 116, 49, 50])
APUMEA = 173
ASSAKQ = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
ATDZXN = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114, 50])
AXADXL = "".join(chr(c) for c in [83, 87, 73, 77, 95, 69, 88, 69, 82, 67, 73, 83, 69])
AXNCUG = "".join(
    chr(c) for c in [83, 105, 110, 103, 108, 101, 80, 117, 109, 112, 75, 101, 121]
)
BDFSRO = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
BDJQRJ = 167
BEKBDF = "".join(
    chr(c) for c in [83, 101, 108, 102, 67, 108, 101, 97, 110, 77, 115, 103]
)
BEXLTP = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 50]
)
BFEGZU = "".join(chr(c) for c in [70, 50])
BGJFJN = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        115,
        85,
        115,
        101,
        100,
    ]
)
BHZVOA = "".join(chr(c) for c in [80, 114, 111, 103, 79, 117, 116, 68, 117, 114])
BIAMJM = 57
BJLOIN = "".join(chr(c) for c in [82, 69, 68])
BMIKGN = 149
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQFYLJ = 60
BQNRXC = "".join(chr(c) for c in [70, 50, 51, 67, 117, 114, 114, 101, 110, 116])
BQSNQL = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
BSIRYX = 1
BSKSOK = 40
BSSUHB = 162
BVHDVR = "".join(chr(c) for c in [90, 111, 110, 101, 50, 76, 101, 100])
BVNAXA = "".join(
    chr(c) for c in [69, 120, 101, 114, 99, 105, 115, 101, 84, 121, 112, 101]
)
BWJYKL = 0
BXYBQS = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
BYGDSB = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        49,
        112,
        104,
        97,
        115,
        101,
        83,
        105,
        110,
        103,
        108,
        101,
        80,
        97,
        99,
        107,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
CBFEGZ = "".join(chr(c) for c in [70, 49])
CCPQIP = 45
CGETIX = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
CHWDAF = "".join(chr(c) for c in [70, 50, 76, 105, 110, 101])
CMCVDS = "".join(chr(c) for c in [79, 70, 70])
CPOUBM = 145
CPQIPO = "".join(chr(c) for c in [79, 117, 116, 49, 49, 67, 117, 114])
CQBMJV = 0
CQFFTT = "".join(chr(c) for c in [67, 72, 73, 76, 76])
CRHYUA = "".join(
    chr(c) for c in [73, 110, 102, 111, 77, 115, 103, 67, 111, 110, 102, 105, 103]
)
CTHBSK = "".join(chr(c) for c in [79, 117, 116, 52, 67, 117, 114])
CTTGCR = "".join(chr(c) for c in [73, 98, 101, 114, 83, 112, 97])
CVDSSR = "".join(chr(c) for c in [83, 76, 69, 69, 80])
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = "".join(chr(c) for c in [79, 117, 116, 49, 49])
CXQIEF = "".join(chr(c) for c in [79, 117, 116, 51])
CYRAPU = "".join(chr(c) for c in [76, 111, 99, 107, 69, 110, 97, 98, 108, 101, 100])
CYWONF = "".join(chr(c) for c in [80, 114, 111, 95, 70, 108, 111, 97, 116])
CZOLSI = "".join(chr(c) for c in [83, 117, 110, 114, 105, 115, 101])
DAFIKJ = 106
DDPMXF = "".join(
    chr(c)
    for c in [67, 117, 115, 116, 111, 109, 75, 101, 121, 69, 110, 97, 98, 108, 101, 100]
)
DGKEAK = 82
DJQRJJ = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        49,
        112,
        104,
        97,
        115,
        101,
        68,
        117,
        97,
        108,
        80,
        97,
        99,
        107,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
DKEYGG = 126
DKHTZB = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
DMPSCT = "".join(chr(c) for c in [73, 100, 111, 108])
DNIBXT = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
DNQGVU = 92
DPMXFU = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 67, 104, 97, 110, 103, 101]
)
DQLAII = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
DRXAIV = "".join(chr(c) for c in [66, 117, 108, 108, 102, 114, 111, 103])
DSBDJQ = 166
DVRIDK = "".join(chr(c) for c in [90, 111, 110, 101, 51, 76, 101, 100])
DXLUBG = 134
DZXNQT = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
EAKSTS = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
ECYXMP = 82
EEZFET = "".join(chr(c) for c in [65, 114, 116, 101, 115, 105, 97, 110])
EFJTAC = "".join(chr(c) for c in [79, 117, 116, 56, 67, 117, 114])
EFXQGL = "".join(chr(c) for c in [79, 117, 116, 53])
EGZUQE = "".join(chr(c) for c in [70, 50, 49])
EJNIBX = 29
EKBDFS = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
EKCWAO = "".join(chr(c) for c in [79, 117, 116, 49, 48])
EKVKZI = 31
ELHBQN = 101
ELWUEU = "".join(chr(c) for c in [87, 72, 73, 84, 69])
EMCGET = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
EMVCYW = "".join(chr(c) for c in [74, 97, 99, 117, 122, 122, 105])
EOCTHB = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
ESVZSS = "".join(chr(c) for c in [65, 115, 115, 105, 103, 110, 86, 83, 80, 51])
ETDRXA = "".join(chr(c) for c in [66, 101, 108, 108, 97, 103, 105, 111])
EUHNNX = "".join(chr(c) for c in [67, 117, 115, 116, 111, 109, 101, 114, 73, 68])
EUTOPH = 83
EVBVHD = "".join(chr(c) for c in [83, 84, 65, 84, 85, 83])
EXLSXU = "".join(chr(c) for c in [76, 105, 110, 101, 51])
EXLTPO = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 51]
)
EYGGVY = "".join(
    chr(c) for c in [78, 117, 109, 98, 101, 114, 79, 102, 90, 111, 110, 101, 115]
)
EZFETD = "".join(chr(c) for c in [65, 114, 99, 116, 105, 99])
FCPOUB = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        53,
    ]
)
FCRTFM = "".join(chr(c) for c in [105, 110, 89, 74])
FEFJTA = 42
FEGZUQ = "".join(chr(c) for c in [70, 51])
FETDRX = "".join(chr(c) for c in [66, 101, 97, 99, 104, 99, 111, 109, 98, 101, 114])
FFTTID = "".join(chr(c) for c in [72, 69, 65, 84, 95, 83, 65, 86, 69, 82])
FIKJPU = 107
FJNTTU = "".join(chr(c) for c in [65, 76, 76, 95, 80, 85, 77, 80, 83])
FJTACC = 43
FLSIJU = 178
FMNHTB = "".join(
    chr(c)
    for c in [
        77,
        105,
        110,
        105,
        109,
        117,
        109,
        73,
        110,
        112,
        117,
        116,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
FOUURI = "".join(chr(c) for c in [90, 111, 110, 101, 49, 76, 101, 100])
FSROGM = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 97, 114, 116]
)
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
FTTIDU = "".join(chr(c) for c in [65, 85, 84, 79, 95, 87, 95, 66, 79, 79, 83, 84])
FUBJLO = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 67, 104, 97, 110, 103, 101]
)
FWRKIN = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
FXQGLR = 16
FYLJUI = 61
FZCZOL = "".join(chr(c) for c in [83, 116, 114, 111, 110, 103])
GCRHYU = 112
GDSBDJ = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        50,
        112,
        104,
        97,
        115,
        101,
        83,
        105,
        110,
        103,
        108,
        101,
        80,
        97,
        99,
        107,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
GETIXQ = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
GGVYKL = "".join(chr(c) for c in [49])
GJFJNT = 135
GKEAKS = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
GMDDPM = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        84,
        104,
        101,
        114,
        97,
        112,
        121,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
GNVFOU = 153
GQPLSP = 32
GSELHB = 100
GTYIYW = "".join(chr(c) for c in [79, 117, 116, 53, 70, 117, 115, 101])
GUCYRA = 113
GVUNXN = "".join(chr(c) for c in [79, 117, 116, 49, 50, 70, 117, 115, 101])
GVYKLT = "".join(chr(c) for c in [50])
GXXYOJ = "".join(chr(c) for c in [65, 83, 95, 49, 50, 86, 95, 83, 85, 80, 80, 76, 89])
GYOUSP = 56
GZUQEX = "".join(chr(c) for c in [70, 50, 50])
HBQNRX = 102
HBSKSO = "".join(chr(c) for c in [79, 117, 116, 53, 67, 117, 114])
HBVWVU = "".join(chr(c) for c in [67, 69])
HBXIBH = 160
HDVRID = "".join(chr(c) for c in [90, 111, 110, 101, 50, 84, 121, 112, 101])
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = 37
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HIUSOO = "".join(chr(c) for c in [55, 65])
HNNXWE = "".join(chr(c) for c in [71, 101, 110, 101, 114, 105, 99])
HSVSIB = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 49]
)
HTBJEU = 74
HTZBBE = "".join(
    chr(c)
    for c in [80, 117, 109, 112, 49, 85, 115, 101, 114, 65, 99, 99, 101, 115, 115]
)
HUGTYI = "".join(chr(c) for c in [79, 117, 116, 52, 70, 117, 115, 101])
HUOJRJ = "".join(chr(c) for c in [49, 65])
HWDAFI = 105
HWOGXX = "".join(chr(c) for c in [90, 79, 78, 69, 50])
HYUAXN = "".join(chr(c) for c in [83, 72, 79, 87, 95, 65, 76, 76, 95, 77, 83, 71])
HZVOAC = 130
IACQFF = "".join(
    chr(c) for c in [67, 111, 111, 108, 90, 111, 110, 101, 77, 111, 100, 101]
)
IAMJMA = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
IBEXLT = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 49]
)
IBHZVO = 128
IBXTIA = "".join(chr(c) for c in [78, 105, 103, 104, 116])
IBXYBQ = 30
ICXQIE = 13
IDKEYG = "".join(chr(c) for c in [90, 111, 110, 101, 52, 76, 101, 100])
IDNIBX = 68
IDUBSS = "".join(chr(c) for c in [66, 79, 84, 72, 95, 72, 69, 65, 84])
IEFXQG = 15
IEVBVH = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
IFJBIA = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
IGYOUS = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
IHBXIB = "".join(
    chr(c)
    for c in [80, 114, 111, 103, 79, 117, 116, 65, 99, 99, 101, 115, 115, 111, 114, 121]
)
IIDNIB = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
IJUGSE = "".join(chr(c) for c in [70, 50, 67, 117, 114, 114, 101, 110, 116])
IJUZMR = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        49,
    ]
)
IKFWRK = "".join(chr(c) for c in [80, 49])
IKGNVF = 151
IKJPUN = "".join(chr(c) for c in [70, 50, 50, 76, 105, 110, 101])
ILXWAJ = "".join(
    chr(c) for c in [80, 114, 101, 115, 115, 117, 114, 101, 83, 119, 105, 116, 99, 104]
)
INELWU = "".join(chr(c) for c in [77, 65, 71, 69, 78, 84, 65])
IPIVLA = "".join(chr(c) for c in [79, 51])
IPMDMP = "".join(chr(c) for c in [79, 107, 101, 97, 110, 111, 115])
IPOUYN = 47
IRYXBQ = 58
IUSOOQ = "".join(chr(c) for c in [56, 65])
IUVMKZ = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 50]
)
IUXFEF = "".join(chr(c) for c in [79, 117, 116, 54, 67, 117, 114])
IVDNQG = 91
IVEMVC = "".join(chr(c) for c in [70, 111, 117, 114, 95, 87, 105, 110, 100])
IVLASS = "".join(chr(c) for c in [72, 84, 82])
IXQVXO = 73
IYWSKW = 88
JBIAMJ = "".join(chr(c) for c in [79, 116, 79, 112, 116, 105, 111, 110])
JEUTOP = "".join(chr(c) for c in [79, 117, 116, 49, 70, 117, 115, 101])
JFJNTT = "".join(chr(c) for c in [78, 79, 95, 80, 85, 77, 80])
JHIUSO = "".join(chr(c) for c in [54, 65])
JIGYOU = 55
JJJVYF = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        51,
        112,
        104,
        97,
        115,
        101,
        68,
        117,
        97,
        108,
        80,
        97,
        99,
        107,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
JJVYFC = 170
JLOINE = "".join(chr(c) for c in [71, 82, 69, 69, 78])
JMCBFE = "".join(
    chr(c) for c in [72, 101, 97, 116, 80, 117, 109, 112, 70, 117, 115, 101]
)
JNTTUV = "".join(chr(c) for c in [80, 50, 95, 84, 79, 95, 80, 53])
JPUNRJ = "".join(chr(c) for c in [70, 50, 51, 76, 105, 110, 101])
JQRJJJ = 168
JRJHIU = "".join(chr(c) for c in [52, 65])
JTACCP = "".join(chr(c) for c in [79, 117, 116, 57, 67, 117, 114])
JUGSEL = 99
JUIKFW = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
JUTYEK = "".join(chr(c) for c in [79, 117, 116, 56])
JUZMRK = 137
JVHFTH = "".join(chr(c) for c in [78, 65])
JVYFCR = "".join(chr(c) for c in [82, 101, 97, 108, 80, 97, 99, 107, 84, 121, 112, 101])
JWMNZM = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101])
JYKLGQ = 118
JYMOUN = 2
JZTATD = 4
KBDFSR = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
KCWAON = 21
KEAKST = 72
KEYGGV = "".join(chr(c) for c in [90, 111, 110, 101, 52, 84, 121, 112, 101])
KGNVFO = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        57,
    ]
)
KHTZBB = 64
KINEJN = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
KJPUNR = 108
KLGQPL = 120
KMLOIJ = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114, 70, 117, 115, 101])
KPHUOJ = "".join(chr(c) for c in [78, 111, 116, 95, 83, 101, 116])
KQTDKH = "".join(chr(c) for c in [65, 109, 80, 109])
KQXPIC = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
KSOKPH = 50
KSTSEM = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
KVFCPO = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        52,
    ]
)
KVKZIL = "".join(
    chr(c) for c in [70, 108, 111, 119, 68, 101, 116, 101, 99, 116, 111, 114]
)
KWIVDN = 90
KXSJWM = 80
KZHWOG = 172
KZILXW = "".join(chr(c) for c in [105, 110, 70, 108, 111])
LAIIDN = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
LASSAK = "".join(chr(c) for c in [70, 97, 110])
LGQPLS = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
LHBQNR = "".join(chr(c) for c in [70, 50, 50, 67, 117, 114, 114, 101, 110, 116])
LIUXFE = 25
LJUIKF = 62
LKXSJW = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
LNMHXE = 33
LOIJUG = "".join(chr(c) for c in [70, 49, 67, 117, 114, 114, 101, 110, 116])
LOINEL = "".join(chr(c) for c in [89, 69, 76, 76, 79, 87])
LRAHEO = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
LSIJUZ = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
    ]
)
LSIPMD = "".join(chr(c) for c in [86, 105, 107, 105, 110, 103])
LSPFTS = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
LSXUJU = "".join(chr(c) for c in [79, 117, 116, 54])
LTPOXI = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 49]
)
LTQLVH = "".join(
    chr(c)
    for c in [
        83,
        116,
        97,
        116,
        117,
        115,
        76,
        105,
        103,
        104,
        116,
        78,
        111,
        114,
        109,
        97,
        108,
        67,
        111,
        108,
        111,
        114,
    ]
)
LUBGJF = "".join(
    chr(c)
    for c in [
        85,
        83,
        69,
        95,
        86,
        65,
        82,
        73,
        65,
        66,
        76,
        69,
        95,
        83,
        80,
        69,
        69,
        68,
        95,
        80,
        85,
        77,
        80,
        83,
    ]
)
MAOAWB = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
MCBFEG = 163
MCGETI = 76
MCVDSS = "".join(chr(c) for c in [69, 67, 79, 78, 79, 77, 89])
MDDPMX = 110
MDMPSC = "".join(chr(c) for c in [68, 101, 108, 117, 120, 101])
MEAOES = "".join(chr(c) for c in [80, 52])
MFZDGK = "".join(
    chr(c) for c in [79, 85, 84, 83, 73, 68, 69, 95, 70, 73, 76, 84, 69, 82]
)
MHXEKV = "".join(chr(c) for c in [67])
MIKGNV = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        56,
    ]
)
MJIGYO = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
MJMAOA = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
MJVHFT = 12
MKQTDK = 34
MKZHWO = "".join(
    chr(c)
    for c in [
        73,
        110,
        77,
        105,
        120,
        90,
        111,
        110,
        101,
        84,
        111,
        70,
        111,
        108,
        108,
        111,
        119,
    ]
)
MLOIJU = 97
MNHTBJ = 122
MOUNBL = 4
MPSCTT = "".join(chr(c) for c in [65, 115, 112, 101, 110])
MRKVFC = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        51,
    ]
)
MVCYWO = "".join(chr(c) for c in [74, 97, 122, 122, 105])
MXFUBJ = "".join(
    chr(c)
    for c in [80, 65, 83, 83, 87, 79, 82, 68, 95, 80, 82, 79, 84, 69, 67, 84, 69, 68]
)
NAXADX = "".join(chr(c) for c in [78, 79, 95, 69, 88, 69, 82, 67, 73, 83, 69])
NBLKXS = "".join(chr(c) for c in [76, 73])
NCUGUC = "".join(chr(c) for c in [70, 111, 114, 90, 111, 110, 101, 115])
NEJNIB = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
NELWUE = "".join(chr(c) for c in [67, 89, 65, 78])
NFZCZO = "".join(
    chr(c)
    for c in [80, 114, 101, 109, 105, 117, 109, 95, 76, 101, 105, 115, 117, 114, 101]
)
NHTBJE = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
NIBXTI = 70
NIBXYB = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
NKMLOI = 96
NMHXEK = "".join(chr(c) for c in [70])
NNXWEE = "".join(chr(c) for c in [72, 121, 100, 114, 111, 112, 111, 111, 108])
NPYYLI = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
NQGVUN = "".join(chr(c) for c in [79, 117, 116, 49, 49, 70, 117, 115, 101])
NQJYMO = "".join(
    chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 65, 115, 67, 80]
)
NQLNMH = 1
NQTMFZ = 10
NRJZTA = 3
NRSJMC = "".join(chr(c) for c in [49, 52, 65])
NRXCHW = "".join(chr(c) for c in [70, 49, 76, 105, 110, 101])
NTTUVR = "".join(chr(c) for c in [80, 51, 95, 84, 79, 95, 80, 53])
NVFOUU = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        49,
        48,
    ]
)
NXNKML = 95
NXWEEZ = "".join(
    chr(c) for c in [69, 110, 100, 108, 101, 115, 115, 80, 111, 111, 108, 115]
)
NZMJIG = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
OACMCV = "".join(chr(c) for c in [83, 105, 108, 101, 110, 116, 77, 111, 100, 101])
OAWBSI = "".join(chr(c) for c in [72, 105])
OCTHBS = 38
OESVZS = 174
OGMDDP = 7
OGXXYO = "".join(chr(c) for c in [90, 79, 78, 69, 52])
OIHBXI = 75
OIJUGS = 98
OINELW = "".join(chr(c) for c in [66, 76, 85, 69])
OJQSGM = "".join(
    chr(c) for c in [83, 65, 77, 69, 95, 65, 83, 95, 78, 79, 82, 77, 65, 76]
)
OJRJHI = "".join(chr(c) for c in [51, 65])
OKPHUO = 161
OLSIPM = "".join(
    chr(c) for c in [83, 112, 97, 95, 73, 110, 100, 117, 115, 116, 114, 105, 101, 115]
)
ONFZCZ = "".join(chr(c) for c in [80, 68, 67])
ONPYYL = 23
OOQNRS = "".join(chr(c) for c in [49, 49, 65])
OPHUGT = "".join(chr(c) for c in [79, 117, 116, 51, 70, 117, 115, 101])
OQNRSJ = "".join(chr(c) for c in [49, 50, 65])
OUBMIK = 147
OUNBLK = "".join(chr(c) for c in [79, 117, 116, 76, 105])
OUSPBW = 81
OUURIE = 123
OUYNQJ = 48
OXIUVM = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 52]
)
PHUGTY = 85
PHUOJR = "".join(chr(c) for c in [48, 65])
PICXQI = "".join(chr(c) for c in [79, 117, 116, 50])
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
PMDMPS = "".join(chr(c) for c in [67, 108, 101, 97, 114, 119, 97, 116, 101, 114])
PMXFUB = "".join(
    chr(c) for c in [78, 79, 95, 82, 69, 83, 84, 82, 73, 67, 84, 73, 79, 78]
)
POUBMI = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        54,
    ]
)
POUYNQ = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
POXIUV = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 51]
)
PQIPOU = 46
PSCTTG = "".join(chr(c) for c in [84, 104, 101, 114, 109, 111, 83, 112, 97, 115])
PUMEAO = "".join(chr(c) for c in [80, 50])
PUNRJZ = 109
PYYLIU = 24
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(chr(c) for c in [76, 105, 110, 101, 50])
QFFTTI = "".join(chr(c) for c in [72, 69, 65, 84, 95, 87, 95, 66, 79, 79, 83, 84])
QFYLJU = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
QGLRAH = 26
QGVUNX = 93
QIEFXQ = "".join(chr(c) for c in [79, 117, 116, 52])
QIPOUY = "".join(chr(c) for c in [79, 117, 116, 49, 50, 67, 117, 114])
QJYMOU = 119
QLAIID = 35
QLNMHX = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
QLVHSV = "".join(chr(c) for c in [79, 82, 65, 78, 71, 69])
QNRSJM = "".join(chr(c) for c in [49, 51, 65])
QNRXCH = 103
QPLSPF = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
QRJJJV = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        50,
        112,
        104,
        97,
        115,
        101,
        68,
        117,
        97,
        108,
        80,
        97,
        99,
        107,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
QSGMEC = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        105,
        110,
        100,
        101,
        114,
        115,
        78,
        111,
        116,
        66,
        108,
        105,
        110,
        107,
        105,
        110,
        103,
        76,
        69,
        68,
    ]
)
QSNQLN = 63
QTDKHT = "".join(chr(c) for c in [50, 52, 104])
QTMFZD = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
QVXOIH = "".join(chr(c) for c in [83, 108, 97, 118, 101])
QXPICX = "".join(chr(c) for c in [65, 85, 88])
RAHEOC = 36
RAPUME = "".join(chr(c) for c in [65, 115, 115, 105, 103, 110, 86, 83, 80, 49])
RAZMKQ = "".join(chr(c) for c in [65, 76, 76, 79, 87, 69, 68])
RFLSIJ = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        66,
        117,
        111,
        121,
        97,
        110,
        99,
        121,
        80,
        117,
        109,
        112,
    ]
)
RHYUAX = "".join(
    chr(c) for c in [72, 73, 68, 69, 95, 68, 69, 84, 65, 73, 76, 69, 68, 95, 77, 83, 71]
)
RIDKEY = "".join(chr(c) for c in [90, 111, 110, 101, 51, 84, 121, 112, 101])
RIEVBV = "".join(chr(c) for c in [90, 111, 110, 101, 49, 84, 121, 112, 101])
RJHIUS = "".join(chr(c) for c in [53, 65])
RJJJVY = 169
RJZTAT = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
RKINEJ = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
RKVFCP = 141
ROGMDD = "".join(
    chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 111, 112]
)
RSJMCB = "".join(chr(c) for c in [49, 53, 65])
RTFMNH = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
RURAZM = "".join(
    chr(c)
    for c in [
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        83,
        105,
        108,
        101,
        110,
        116,
        84,
        111,
        82,
        101,
        103,
        117,
        108,
        97,
        116,
        101,
    ]
)
RXAIVE = "".join(chr(c) for c in [67, 111, 97, 115, 116])
RXCHWD = 104
RYXBQF = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
SAKQXP = "".join(chr(c) for c in [80, 114, 111, 116, 101, 99, 116, 105, 111, 110])
SBDJQR = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        51,
        112,
        104,
        97,
        115,
        101,
        83,
        105,
        110,
        103,
        108,
        101,
        80,
        97,
        99,
        107,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
SBVNAX = 177
SCTTGC = "".join(chr(c) for c in [84, 105, 116, 97, 110, 95, 83, 112, 97, 115])
SELHBQ = "".join(chr(c) for c in [70, 50, 49, 67, 117, 114, 114, 101, 110, 116])
SEMCGE = 5
SIBEXL = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 52]
)
SIFJBI = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
SIJUZM = 136
SIPMDM = "".join(
    chr(c) for c in [87, 87, 79, 95, 87, 104, 105, 114, 108, 99, 97, 114, 101]
)
SIRYXB = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
SJWMNZ = 180
SKSOKP = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
SKWIVD = "".join(chr(c) for c in [79, 117, 116, 56, 70, 117, 115, 101])
SNQLNM = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
SOKPHU = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 80, 117, 109, 112, 67, 117, 114, 114, 101, 110, 116]
)
SOOQNR = "".join(chr(c) for c in [49, 48, 65])
SPBWJY = "".join(chr(c) for c in [79, 119, 110])
SPFTSI = "".join(
    chr(c) for c in [70, 105, 108, 116, 80, 49, 68, 117, 114, 79, 110, 108, 121]
)
SROGMD = 6
SRURAZ = 158
SSAKQX = "".join(chr(c) for c in [79, 78, 90, 69, 78])
SSBVNA = "".join(chr(c) for c in [65, 115, 115, 105, 103, 110, 86, 83, 80, 53])
SSRURA = "".join(
    chr(c) for c in [83, 105, 108, 101, 110, 116, 68, 117, 114, 97, 116, 105, 111, 110]
)
SSUHBV = "".join(chr(c) for c in [85, 76, 95, 67, 69])
STSEMC = "".join(
    chr(c) for c in [65, 117, 120, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
SUHBVW = 51
SVSIBE = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 50]
)
SVZSSB = 175
SXUJUT = 17
TACCPQ = 44
TATDZX = 6
TBJEUT = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
TDRXAI = "".join(
    chr(c)
    for c in [76, 101, 105, 115, 117, 114, 101, 95, 80, 114, 111, 100, 95, 73, 110, 100]
)
TDZXNQ = 116
TFMNHT = 53
TGCRHY = "".join(
    chr(c)
    for c in [
        77,
        111,
        100,
        101,
        75,
        101,
        121,
        65,
        115,
        73,
        110,
        118,
        101,
        114,
        116,
        68,
        105,
        115,
        112,
        108,
        97,
        121,
        75,
        101,
        121,
    ]
)
THBSKS = 39
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = 77
TIDUBS = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76, 95, 72, 69, 65, 84])
TIXQVX = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
TMFZDG = 71
TOPHUG = 84
TPOXIU = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 50]
)
TQLVHS = "".join(chr(c) for c in [80, 85, 82, 80, 76, 69])
TSEMCG = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        99,
        107,
        79,
        110,
        79,
        102,
        102,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
TSIFJB = 27
TTIDUB = "".join(chr(c) for c in [65, 85, 84, 79, 95, 83, 65, 86, 69, 82])
TTUVRF = "".join(chr(c) for c in [80, 52, 95, 65, 78, 68, 95, 80, 53])
TUVRFL = "".join(chr(c) for c in [80, 53, 95, 79, 78, 76, 89])
TYEKCW = "".join(chr(c) for c in [79, 117, 116, 57])
TYIYWS = 87
TZBBEK = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
UAXNCU = "".join(
    chr(c)
    for c in [
        76,
        111,
        119,
        101,
        114,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
        77,
        101,
        110,
        117,
    ]
)
UBJLOI = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        67,
        111,
        108,
        111,
        114,
    ]
)
UBMIKG = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        55,
    ]
)
UBSSUH = "".join(
    chr(c)
    for c in [
        71,
        101,
        110,
        101,
        114,
        105,
        99,
        72,
        101,
        97,
        116,
        80,
        117,
        109,
        112,
        73,
        68,
    ]
)
UBYGDS = 52
UCYRAP = "".join(
    chr(c)
    for c in [
        68,
        101,
        97,
        108,
        101,
        114,
        76,
        111,
        99,
        107,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
UEUHNN = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        69,
        100,
        105,
        116,
    ]
)
UGSELH = "".join(chr(c) for c in [70, 51, 67, 117, 114, 114, 101, 110, 116])
UGTYIY = 86
UGUCYR = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
)
UHBVWV = "".join(chr(c) for c in [85, 76])
UHNNXW = 111
UIKFWR = 78
UJUTYE = 18
UMEAOE = "".join(chr(c) for c in [80, 51])
UNBLKX = 79
UNRJZT = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
UNXNKM = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 49, 70, 117, 115, 101])
UOJRJH = "".join(chr(c) for c in [50, 65])
UQEXLS = "".join(chr(c) for c in [76, 105, 110, 101, 49])
URAZMK = "".join(chr(c) for c in [78, 79, 84, 95, 65, 76, 76, 79, 87, 69, 68])
USOOQN = "".join(chr(c) for c in [57, 65])
USPBWJ = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
UTOPHU = "".join(chr(c) for c in [79, 117, 116, 50, 70, 117, 115, 101])
UTYEKC = 19
UURIEV = "".join(chr(c) for c in [82, 71, 66])
UVMKZH = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 51]
)
UXFEFJ = 41
UYNQJY = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50, 67, 117, 114])
UZMRKV = "".join(
    chr(c)
    for c in [
        69,
        120,
        99,
        101,
        114,
        99,
        105,
        115,
        101,
        80,
        117,
        109,
        112,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
        50,
    ]
)
VCYWON = "".join(chr(c) for c in [76, 65])
VDNQGV = "".join(chr(c) for c in [79, 117, 116, 49, 48, 70, 117, 115, 101])
VDQLAI = 3
VDSSRU = "".join(chr(c) for c in [78, 73, 71, 72, 84])
VEMVCY = "".join(chr(c) for c in [72, 111, 116, 115, 112, 114, 105, 110, 103])
VFCPOU = 143
VFOUUR = 155
VHDVRI = 124
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VHSVSI = "".join(
    chr(c) for c in [77, 97, 112, 112, 105, 110, 103, 69, 110, 97, 98, 108, 101]
)
VKZILX = 164
VLASSA = "".join(chr(c) for c in [])
VMKZHW = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 52]
)
VNAXAD = 133
VOACMC = 132
VRFLSI = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        68,
        101,
        100,
        105,
        99,
        97,
        116,
        101,
        100,
        80,
        117,
        109,
        112,
        115,
    ]
)
VRIDKE = 125
VSIBEX = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 51]
)
VUBYGD = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
VUNXNK = 94
VWVUBY = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        80,
        104,
        97,
        115,
        101,
        115,
    ]
)
VYFCRT = 171
VYKLTQ = "".join(chr(c) for c in [51])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
VZSSBV = "".join(chr(c) for c in [65, 115, 115, 105, 103, 110, 86, 83, 80, 52])
WAJVDQ = "".join(chr(c) for c in [73, 110, 116, 111, 80, 105, 112, 105, 110, 103])
WAONPY = 22
WBSIRY = "".join(
    chr(c) for c in [65, 117, 120, 65, 115, 66, 117, 98, 98, 108, 101, 71, 101, 110]
)
WDAFIK = "".join(chr(c) for c in [70, 51, 76, 105, 110, 101])
WEEZFE = "".join(chr(c) for c in [65, 108, 112, 115])
WIVDNQ = "".join(chr(c) for c in [79, 117, 116, 57, 70, 117, 115, 101])
WJYKLG = "".join(
    chr(c)
    for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 84, 105, 109, 101, 79, 117, 116]
)
WMNZMJ = "".join(chr(c) for c in [69, 110, 97, 98, 108, 101])
WOGXXY = "".join(chr(c) for c in [90, 79, 78, 69, 51])
WONFZC = "".join(chr(c) for c in [77, 97, 114, 113, 117, 105, 115])
WRKINE = 28
WSKWIV = 89
WUEUHN = 8
WVUBYG = 114
XAIVEM = "".join(
    chr(c) for c in [68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 111, 110, 101]
)
XBQFYL = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
XEKVKZ = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
XFEFJT = "".join(chr(c) for c in [79, 117, 116, 55, 67, 117, 114])
XIBHZV = "".join(
    chr(c) for c in [80, 114, 111, 103, 79, 117, 116, 83, 116, 97, 114, 116]
)
XIUVMK = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 49]
)
XLTPOX = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 52]
)
XLUBGJ = "".join(
    chr(c)
    for c in [85, 83, 69, 95, 83, 84, 65, 78, 68, 65, 82, 68, 95, 80, 85, 77, 80, 83]
)
XNCUGU = "".join(chr(c) for c in [70, 111, 114, 83, 112, 101, 101, 100, 115])
XNKMLO = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50, 70, 117, 115, 101])
XNQTMF = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
XOIHBX = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
XQGLRA = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
XQIEFX = 14
XQVXOI = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
XSJWMN = "".join(
    chr(c)
    for c in [
        76,
        105,
        103,
        104,
        116,
        65,
        99,
        116,
        105,
        118,
        97,
        116,
        105,
        111,
        110,
        83,
        97,
        102,
        101,
        116,
        121,
    ]
)
XTIACQ = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
XUJUTY = "".join(chr(c) for c in [79, 117, 116, 55])
XWAJVD = "".join(
    chr(c) for c in [80, 114, 111, 98, 101, 76, 111, 99, 97, 116, 105, 111, 110]
)
XWEEZF = "".join(chr(c) for c in [87, 101, 108, 108, 105, 115])
XYBQSN = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
XYOJQS = "".join(
    chr(c)
    for c in [
        83,
        116,
        97,
        116,
        117,
        115,
        76,
        105,
        103,
        104,
        116,
        82,
        101,
        109,
        105,
        110,
        100,
        101,
        114,
        115,
        67,
        111,
        108,
        111,
        114,
    ]
)
YEKCWA = 20
YFCRTF = "".join(chr(c) for c in [105, 110, 89, 84])
YGDSBD = 165
YGGVYK = 127
YIYWSK = "".join(chr(c) for c in [79, 117, 116, 54, 70, 117, 115, 101])
YKLGQP = "".join(chr(c) for c in [65, 117, 120, 84, 105, 109, 101, 79, 117, 116])
YKLTQL = "".join(chr(c) for c in [52])
YLIUXF = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50])
YLJUIK = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
YMOUNB = "".join(
    chr(c)
    for c in [
        87,
        97,
        116,
        101,
        114,
        102,
        97,
        108,
        108,
        86,
        97,
        108,
        118,
        101,
        79,
        110,
        67,
        80,
    ]
)
YNQJYM = 49
YOJQSG = 179
YOUSPB = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YRAPUM = 121
YWONFZ = "".join(chr(c) for c in [77, 65, 65, 88])
YWSKWI = "".join(chr(c) for c in [79, 117, 116, 55, 70, 117, 115, 101])
YXBQFY = 59
YYPIPI = "".join(chr(c) for c in [80, 53])
ZBBEKB = "".join(
    chr(c) for c in [72, 105, 103, 104, 83, 112, 101, 101, 100, 79, 110, 108, 121]
)
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZCZOLS = "".join(chr(c) for c in [83, 117, 110, 114, 97, 110, 115])
ZDGKEA = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
ZFETDR = "".join(chr(c) for c in [66, 97, 114, 101, 102, 111, 111, 116])
ZHWOGX = "".join(chr(c) for c in [90, 79, 78, 69, 49])
ZILXWA = "".join(
    chr(c) for c in [78, 111, 116, 73, 110, 115, 116, 97, 108, 108, 101, 100]
)
ZMJIGY = 54
ZMKQTD = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
ZMRKVF = 139
ZOLSIP = "".join(
    chr(c) for c in [83, 117, 112, 101, 114, 105, 111, 114, 83, 112, 97, 115]
)
ZSSBVN = 176
ZTATDZ = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
ZUQEXL = "".join(chr(c) for c in [70, 50, 51])
ZVOACM = "".join(chr(c) for c in [80, 114, 111, 103, 79, 117, 116, 70, 114, 101, 113])
ZXNQTM = 8
AWBSIR = [AOAWBS, OAWBSI]
AZMKQT = [URAZMK, RAZMKQ]
BBEKBD = [TZBBEK, ZBBEKB]
BJEUTO = [BXYBQS, TBJEUT]
BLKXSJ = [
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    NBLKXS,
]
BVWVUB = [UHBVWV, HBVWVU]
BXIBHZ = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIVLAS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    SSAKQX,
    VLASSA,
    VLASSA,
    VLASSA,
    QXPICX,
]
BXTIAC = [BXYBQS, IBXTIA]
CRTFMN = [
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    YFCRTF,
    VLASSA,
    FCRTFM,
]
CUGUCY = [JVHFTH, XNCUGU, NCUGUC, VLASSA]
DFSROG = [KBDFSR, BDFSRO]
DSSRUR = [JVHFTH, CMCVDS, MCVDSS, CVDSSR, VDSSRU]
DUBSSU = [CQFFTT, QFFTTI, FFTTID, FTTIDU, TTIDUB, TIDUBS, IDUBSS]
EAOESV = [JVHFTH, IKFWRK, PUMEAO, UMEAOE, MEAOES, YYPIPI]
ETIXQV = [CGETIX, GETIXQ]
FJBIAM = [SIFJBI, IFJBIA]
FZDGKE = [JVHFTH, SIFJBI, MFZDGK]
GLRAHE = [
    JVHFTH,
    VHFTHE,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    IVLASS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    AKQXPI,
]
GMECYX = [NBLKXS]
HXEKVK = [NMHXEK, MHXEKV]
INEJNI = [RKINEJ, KINEJN]
JMAOAW = [IAMJMA, AMJMAO, MJMAOA]
JNIBXY = [PIPIVL, IKFWRK]
JQSGME = [OJQSGM, ELWUEU, JLOINE, TQLVHS, LOINEL, NELWUE, QLVHSV, CMCVDS]
JVDQLA = [WAJVDQ, AJVDQL]
KFWRKI = [JVHFTH, IKFWRK, PIPIVL]
KLTQLV = [VLASSA, GGVYKL, GVYKLT, VYKLTQ, YKLTQL]
LVHSVS = [OINELW, ELWUEU, JLOINE, TQLVHS, LOINEL, NELWUE, QLVHSV, CMCVDS]
LWUEUH = [CMCVDS, BJLOIN, JLOINE, LOINEL, OINELW, INELWU, NELWUE, ELWUEU]
LXWAJV = [KZILXW, ZILXWA, ILXWAJ]
MECYXM = []
MNZMJI = [JWMNZM, WMNZMJ]
PBWJYK = [USPBWJ, SPBWJY]
PFTSIF = [QPLSPF, PLSPFT, LSPFTS, SPFTSI]
SGMECY = [
    BMJVHF,
    PICXQI,
    CXQIEF,
    QIEFXQ,
    EFXQGL,
    XQGLRA,
    SOKPHU,
    JMCBFE,
    LSXUJU,
    XUJUTY,
    JUTYEK,
    TYEKCW,
    EKCWAO,
    CWAONP,
    AONPYY,
    NPYYLI,
    YLIUXF,
    OUNBLK,
    XSJWMN,
]
SJMCBF = [
    KPHUOJ,
    PHUOJR,
    HUOJRJ,
    UOJRJH,
    OJRJHI,
    JRJHIU,
    RJHIUS,
    JHIUSO,
    HIUSOO,
    IUSOOQ,
    USOOQN,
    SOOQNR,
    OOQNRS,
    OQNRSJ,
    QNRSJM,
    NRSJMC,
    RSJMCB,
]
TDKHTZ = [JVHFTH, KQTDKH, QTDKHT]
TTGCRH = [
    HNNXWE,
    NNXWEE,
    NXWEEZ,
    XWEEZF,
    WEEZFE,
    EEZFET,
    EZFETD,
    ZFETDR,
    FETDRX,
    ETDRXA,
    TDRXAI,
    DRXAIV,
    RXAIVE,
    XAIVEM,
    AIVEMV,
    IVEMVC,
    VEMVCY,
    EMVCYW,
    MVCYWO,
    VCYWON,
    CYWONF,
    YWONFZ,
    WONFZC,
    ONFZCZ,
    NFZCZO,
    FZCZOL,
    ZCZOLS,
    CZOLSI,
    ZOLSIP,
    OLSIPM,
    LSIPMD,
    SIPMDM,
    IPMDMP,
    PMDMPS,
    MDMPSC,
    DMPSCT,
    MPSCTT,
    PSCTTG,
    SCTTGC,
    CTTGCR,
]
UBGJFJ = [XLUBGJ, LUBGJF]
URIEVB = [UURIEV, ELWUEU]
UVRFLS = [JFJNTT, FJNTTU, JNTTUV, NTTUVR, TTUVRF, TUVRFL, VLASSA, VLASSA]
VBVHDV = [IEVBVH, EVBVHD]
VXOIHB = [VLASSA, XQVXOI, QVXOIH]
XADXLU = [NAXADX, AXADXL]
XCHWDA = [VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, UQEXLS, QEXLSX, EXLSXU]
XFUBJL = [PMXFUB, MXFUBJ]
XLSXUJ = [CBFEGZ, BFEGZU, FEGZUQ, EGZUQE, GZUQEX, ZUQEXL, UQEXLS, QEXLSX, EXLSXU]
XPICXQ = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    LASSAK,
    VLASSA,
    VLASSA,
    ASSAKQ,
    VLASSA,
    VLASSA,
    VLASSA,
    SSAKQX,
    SAKQXP,
    AKQXPI,
    KQXPIC,
    QXPICX,
]
XXYOJQ = [ZHWOGX, HWOGXX, WOGXXY, OGXXYO, GXXYOJ]
YBQSNQ = [BXYBQS, XYBQSN]
YUAXNC = [RHYUAX, HYUAXN, VLASSA, VLASSA]
YYLIUX = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIPIVL,
]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return ECYXMP

    @property
    def output_keys(self):
        return SGMECY

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, XPICXQ, None, None, QBMJVH
            ),
            PICXQI: GeckoEnumStructAccessor(
                self.struct, PICXQI, ICXQIE, None, XPICXQ, None, None, QBMJVH
            ),
            CXQIEF: GeckoEnumStructAccessor(
                self.struct, CXQIEF, XQIEFX, None, XPICXQ, None, None, QBMJVH
            ),
            QIEFXQ: GeckoEnumStructAccessor(
                self.struct, QIEFXQ, IEFXQG, None, XPICXQ, None, None, QBMJVH
            ),
            EFXQGL: GeckoEnumStructAccessor(
                self.struct, EFXQGL, FXQGLR, None, XPICXQ, None, None, QBMJVH
            ),
            XQGLRA: GeckoEnumStructAccessor(
                self.struct, XQGLRA, QGLRAH, None, GLRAHE, None, None, QBMJVH
            ),
            LRAHEO: GeckoByteStructAccessor(self.struct, LRAHEO, RAHEOC, QBMJVH),
            AHEOCT: GeckoByteStructAccessor(self.struct, AHEOCT, HEOCTH, QBMJVH),
            EOCTHB: GeckoByteStructAccessor(self.struct, EOCTHB, OCTHBS, QBMJVH),
            CTHBSK: GeckoByteStructAccessor(self.struct, CTHBSK, THBSKS, QBMJVH),
            HBSKSO: GeckoByteStructAccessor(self.struct, HBSKSO, BSKSOK, QBMJVH),
            SKSOKP: GeckoByteStructAccessor(self.struct, SKSOKP, KSOKPH, QBMJVH),
            SOKPHU: GeckoEnumStructAccessor(
                self.struct, SOKPHU, OKPHUO, None, SJMCBF, None, None, QBMJVH
            ),
            JMCBFE: GeckoEnumStructAccessor(
                self.struct, JMCBFE, MCBFEG, None, XLSXUJ, None, None, QBMJVH
            ),
            LSXUJU: GeckoEnumStructAccessor(
                self.struct, LSXUJU, SXUJUT, None, XPICXQ, None, None, QBMJVH
            ),
            XUJUTY: GeckoEnumStructAccessor(
                self.struct, XUJUTY, UJUTYE, None, XPICXQ, None, None, QBMJVH
            ),
            JUTYEK: GeckoEnumStructAccessor(
                self.struct, JUTYEK, UTYEKC, None, XPICXQ, None, None, QBMJVH
            ),
            TYEKCW: GeckoEnumStructAccessor(
                self.struct, TYEKCW, YEKCWA, None, XPICXQ, None, None, QBMJVH
            ),
            EKCWAO: GeckoEnumStructAccessor(
                self.struct, EKCWAO, KCWAON, None, XPICXQ, None, None, QBMJVH
            ),
            CWAONP: GeckoEnumStructAccessor(
                self.struct, CWAONP, WAONPY, None, XPICXQ, None, None, QBMJVH
            ),
            AONPYY: GeckoEnumStructAccessor(
                self.struct, AONPYY, ONPYYL, None, XPICXQ, None, None, QBMJVH
            ),
            NPYYLI: GeckoEnumStructAccessor(
                self.struct, NPYYLI, PYYLIU, None, YYLIUX, None, None, QBMJVH
            ),
            YLIUXF: GeckoEnumStructAccessor(
                self.struct, YLIUXF, LIUXFE, None, YYLIUX, None, None, QBMJVH
            ),
            IUXFEF: GeckoByteStructAccessor(self.struct, IUXFEF, UXFEFJ, QBMJVH),
            XFEFJT: GeckoByteStructAccessor(self.struct, XFEFJT, FEFJTA, QBMJVH),
            EFJTAC: GeckoByteStructAccessor(self.struct, EFJTAC, FJTACC, QBMJVH),
            JTACCP: GeckoByteStructAccessor(self.struct, JTACCP, TACCPQ, QBMJVH),
            ACCPQI: GeckoByteStructAccessor(self.struct, ACCPQI, CCPQIP, QBMJVH),
            CPQIPO: GeckoByteStructAccessor(self.struct, CPQIPO, PQIPOU, QBMJVH),
            QIPOUY: GeckoByteStructAccessor(self.struct, QIPOUY, IPOUYN, QBMJVH),
            POUYNQ: GeckoByteStructAccessor(self.struct, POUYNQ, OUYNQJ, QBMJVH),
            UYNQJY: GeckoByteStructAccessor(self.struct, UYNQJY, YNQJYM, QBMJVH),
            NQJYMO: GeckoBoolStructAccessor(
                self.struct, NQJYMO, QJYMOU, JYMOUN, QBMJVH
            ),
            YMOUNB: GeckoBoolStructAccessor(
                self.struct, YMOUNB, QJYMOU, MOUNBL, QBMJVH
            ),
            OUNBLK: GeckoEnumStructAccessor(
                self.struct, OUNBLK, UNBLKX, None, BLKXSJ, None, None, None
            ),
            LKXSJW: GeckoByteStructAccessor(self.struct, LKXSJW, KXSJWM, None),
            XSJWMN: GeckoEnumStructAccessor(
                self.struct, XSJWMN, SJWMNZ, None, MNZMJI, None, None, None
            ),
            NZMJIG: GeckoByteStructAccessor(self.struct, NZMJIG, ZMJIGY, QBMJVH),
            MJIGYO: GeckoByteStructAccessor(self.struct, MJIGYO, JIGYOU, QBMJVH),
            IGYOUS: GeckoByteStructAccessor(self.struct, IGYOUS, GYOUSP, QBMJVH),
            YOUSPB: GeckoEnumStructAccessor(
                self.struct, YOUSPB, OUSPBW, BWJYKL, PBWJYK, None, JYMOUN, QBMJVH
            ),
            WJYKLG: GeckoByteStructAccessor(self.struct, WJYKLG, JYKLGQ, QBMJVH),
            YKLGQP: GeckoByteStructAccessor(self.struct, YKLGQP, KLGQPL, QBMJVH),
            LGQPLS: GeckoEnumStructAccessor(
                self.struct, LGQPLS, GQPLSP, None, PFTSIF, None, None, QBMJVH
            ),
            FTSIFJ: GeckoEnumStructAccessor(
                self.struct, FTSIFJ, TSIFJB, None, FJBIAM, None, None, QBMJVH
            ),
            JBIAMJ: GeckoEnumStructAccessor(
                self.struct, JBIAMJ, BIAMJM, None, JMAOAW, None, None, QBMJVH
            ),
            MAOAWB: GeckoEnumStructAccessor(
                self.struct, MAOAWB, OUSPBW, JYMOUN, AWBSIR, None, JYMOUN, QBMJVH
            ),
            WBSIRY: GeckoBoolStructAccessor(
                self.struct, WBSIRY, QJYMOU, BSIRYX, QBMJVH
            ),
            SIRYXB: GeckoByteStructAccessor(self.struct, SIRYXB, IRYXBQ, QBMJVH),
            RYXBQF: GeckoByteStructAccessor(self.struct, RYXBQF, YXBQFY, QBMJVH),
            XBQFYL: GeckoByteStructAccessor(self.struct, XBQFYL, BQFYLJ, QBMJVH),
            QFYLJU: GeckoByteStructAccessor(self.struct, QFYLJU, FYLJUI, QBMJVH),
            YLJUIK: GeckoByteStructAccessor(self.struct, YLJUIK, LJUIKF, QBMJVH),
            JUIKFW: GeckoEnumStructAccessor(
                self.struct, JUIKFW, UIKFWR, None, KFWRKI, None, None, QBMJVH
            ),
            FWRKIN: GeckoEnumStructAccessor(
                self.struct, FWRKIN, WRKINE, None, INEJNI, None, None, QBMJVH
            ),
            NEJNIB: GeckoEnumStructAccessor(
                self.struct, NEJNIB, EJNIBX, None, JNIBXY, None, None, QBMJVH
            ),
            NIBXYB: GeckoEnumStructAccessor(
                self.struct, NIBXYB, IBXYBQ, None, YBQSNQ, None, None, QBMJVH
            ),
            BQSNQL: GeckoByteStructAccessor(self.struct, BQSNQL, QSNQLN, QBMJVH),
            SNQLNM: GeckoTempStructAccessor(self.struct, SNQLNM, NQLNMH, QBMJVH),
            QLNMHX: GeckoEnumStructAccessor(
                self.struct, QLNMHX, LNMHXE, None, HXEKVK, None, None, QBMJVH
            ),
            XEKVKZ: GeckoEnumStructAccessor(
                self.struct, XEKVKZ, EKVKZI, None, JNIBXY, None, None, QBMJVH
            ),
            KVKZIL: GeckoEnumStructAccessor(
                self.struct, KVKZIL, VKZILX, None, LXWAJV, None, None, QBMJVH
            ),
            XWAJVD: GeckoEnumStructAccessor(
                self.struct, XWAJVD, OUSPBW, VDQLAI, JVDQLA, None, JYMOUN, QBMJVH
            ),
            DQLAII: GeckoByteStructAccessor(self.struct, DQLAII, QLAIID, QBMJVH),
            LAIIDN: GeckoTempStructAccessor(self.struct, LAIIDN, AIIDNI, QBMJVH),
            IIDNIB: GeckoTempStructAccessor(self.struct, IIDNIB, IDNIBX, QBMJVH),
            DNIBXT: GeckoEnumStructAccessor(
                self.struct, DNIBXT, NIBXTI, None, BXTIAC, None, None, QBMJVH
            ),
            XTIACQ: GeckoByteStructAccessor(self.struct, XTIACQ, TIACQF, QBMJVH),
            IACQFF: GeckoEnumStructAccessor(
                self.struct, IACQFF, ACQFFT, None, DUBSSU, None, None, QBMJVH
            ),
            UBSSUH: GeckoByteStructAccessor(self.struct, UBSSUH, BSSUHB, QBMJVH),
            SSUHBV: GeckoEnumStructAccessor(
                self.struct, SSUHBV, SUHBVW, None, BVWVUB, None, None, QBMJVH
            ),
            VWVUBY: GeckoByteStructAccessor(self.struct, VWVUBY, WVUBYG, QBMJVH),
            VUBYGD: GeckoByteStructAccessor(self.struct, VUBYGD, UBYGDS, QBMJVH),
            BYGDSB: GeckoByteStructAccessor(self.struct, BYGDSB, YGDSBD, QBMJVH),
            GDSBDJ: GeckoByteStructAccessor(self.struct, GDSBDJ, DSBDJQ, QBMJVH),
            SBDJQR: GeckoByteStructAccessor(self.struct, SBDJQR, BDJQRJ, QBMJVH),
            DJQRJJ: GeckoByteStructAccessor(self.struct, DJQRJJ, JQRJJJ, QBMJVH),
            QRJJJV: GeckoByteStructAccessor(self.struct, QRJJJV, RJJJVY, QBMJVH),
            JJJVYF: GeckoByteStructAccessor(self.struct, JJJVYF, JJVYFC, QBMJVH),
            JVYFCR: GeckoEnumStructAccessor(
                self.struct, JVYFCR, VYFCRT, None, CRTFMN, None, None, None
            ),
            RTFMNH: GeckoByteStructAccessor(self.struct, RTFMNH, TFMNHT, QBMJVH),
            FMNHTB: GeckoByteStructAccessor(self.struct, FMNHTB, MNHTBJ, QBMJVH),
            NHTBJE: GeckoEnumStructAccessor(
                self.struct, NHTBJE, HTBJEU, None, BJEUTO, None, None, QBMJVH
            ),
            JEUTOP: GeckoEnumStructAccessor(
                self.struct, JEUTOP, EUTOPH, None, XLSXUJ, None, None, QBMJVH
            ),
            UTOPHU: GeckoEnumStructAccessor(
                self.struct, UTOPHU, TOPHUG, None, XLSXUJ, None, None, QBMJVH
            ),
            OPHUGT: GeckoEnumStructAccessor(
                self.struct, OPHUGT, PHUGTY, None, XLSXUJ, None, None, QBMJVH
            ),
            HUGTYI: GeckoEnumStructAccessor(
                self.struct, HUGTYI, UGTYIY, None, XLSXUJ, None, None, QBMJVH
            ),
            GTYIYW: GeckoEnumStructAccessor(
                self.struct, GTYIYW, TYIYWS, None, XLSXUJ, None, None, QBMJVH
            ),
            YIYWSK: GeckoEnumStructAccessor(
                self.struct, YIYWSK, IYWSKW, None, XLSXUJ, None, None, QBMJVH
            ),
            YWSKWI: GeckoEnumStructAccessor(
                self.struct, YWSKWI, WSKWIV, None, XLSXUJ, None, None, QBMJVH
            ),
            SKWIVD: GeckoEnumStructAccessor(
                self.struct, SKWIVD, KWIVDN, None, XLSXUJ, None, None, QBMJVH
            ),
            WIVDNQ: GeckoEnumStructAccessor(
                self.struct, WIVDNQ, IVDNQG, None, XLSXUJ, None, None, QBMJVH
            ),
            VDNQGV: GeckoEnumStructAccessor(
                self.struct, VDNQGV, DNQGVU, None, XLSXUJ, None, None, QBMJVH
            ),
            NQGVUN: GeckoEnumStructAccessor(
                self.struct, NQGVUN, QGVUNX, None, XLSXUJ, None, None, QBMJVH
            ),
            GVUNXN: GeckoEnumStructAccessor(
                self.struct, GVUNXN, VUNXNK, None, XLSXUJ, None, None, QBMJVH
            ),
            UNXNKM: GeckoEnumStructAccessor(
                self.struct, UNXNKM, NXNKML, None, XLSXUJ, None, None, QBMJVH
            ),
            XNKMLO: GeckoEnumStructAccessor(
                self.struct, XNKMLO, NKMLOI, None, XLSXUJ, None, None, QBMJVH
            ),
            KMLOIJ: GeckoEnumStructAccessor(
                self.struct, KMLOIJ, MLOIJU, None, XLSXUJ, None, None, QBMJVH
            ),
            LOIJUG: GeckoByteStructAccessor(self.struct, LOIJUG, OIJUGS, QBMJVH),
            IJUGSE: GeckoByteStructAccessor(self.struct, IJUGSE, JUGSEL, QBMJVH),
            UGSELH: GeckoByteStructAccessor(self.struct, UGSELH, GSELHB, QBMJVH),
            SELHBQ: GeckoByteStructAccessor(self.struct, SELHBQ, ELHBQN, QBMJVH),
            LHBQNR: GeckoByteStructAccessor(self.struct, LHBQNR, HBQNRX, QBMJVH),
            BQNRXC: GeckoByteStructAccessor(self.struct, BQNRXC, QNRXCH, QBMJVH),
            NRXCHW: GeckoEnumStructAccessor(
                self.struct, NRXCHW, RXCHWD, None, XCHWDA, None, None, QBMJVH
            ),
            CHWDAF: GeckoEnumStructAccessor(
                self.struct, CHWDAF, HWDAFI, None, XCHWDA, None, None, QBMJVH
            ),
            WDAFIK: GeckoEnumStructAccessor(
                self.struct, WDAFIK, DAFIKJ, None, XCHWDA, None, None, QBMJVH
            ),
            AFIKJP: GeckoEnumStructAccessor(
                self.struct, AFIKJP, FIKJPU, None, XCHWDA, None, None, QBMJVH
            ),
            IKJPUN: GeckoEnumStructAccessor(
                self.struct, IKJPUN, KJPUNR, None, XCHWDA, None, None, QBMJVH
            ),
            JPUNRJ: GeckoEnumStructAccessor(
                self.struct, JPUNRJ, PUNRJZ, None, XCHWDA, None, None, QBMJVH
            ),
            UNRJZT: GeckoByteStructAccessor(self.struct, UNRJZT, NRJZTA, QBMJVH),
            RJZTAT: GeckoTimeStructAccessor(self.struct, RJZTAT, JZTATD, QBMJVH),
            ZTATDZ: GeckoTimeStructAccessor(self.struct, ZTATDZ, TATDZX, QBMJVH),
            ATDZXN: GeckoTimeStructAccessor(self.struct, ATDZXN, TDZXNQ, QBMJVH),
            DZXNQT: GeckoTimeStructAccessor(self.struct, DZXNQT, ZXNQTM, QBMJVH),
            XNQTMF: GeckoTimeStructAccessor(self.struct, XNQTMF, NQTMFZ, QBMJVH),
            QTMFZD: GeckoEnumStructAccessor(
                self.struct, QTMFZD, TMFZDG, None, FZDGKE, None, None, QBMJVH
            ),
            ZDGKEA: GeckoBoolStructAccessor(
                self.struct, ZDGKEA, DGKEAK, BWJYKL, QBMJVH
            ),
            GKEAKS: GeckoBoolStructAccessor(
                self.struct, GKEAKS, KEAKST, JYMOUN, QBMJVH
            ),
            EAKSTS: GeckoBoolStructAccessor(
                self.struct, EAKSTS, KEAKST, BWJYKL, QBMJVH
            ),
            AKSTSE: GeckoBoolStructAccessor(
                self.struct, AKSTSE, KEAKST, BSIRYX, QBMJVH
            ),
            KSTSEM: GeckoBoolStructAccessor(
                self.struct, KSTSEM, KEAKST, VDQLAI, QBMJVH
            ),
            STSEMC: GeckoBoolStructAccessor(
                self.struct, STSEMC, KEAKST, MOUNBL, QBMJVH
            ),
            TSEMCG: GeckoBoolStructAccessor(
                self.struct, TSEMCG, KEAKST, SEMCGE, QBMJVH
            ),
            EMCGET: GeckoEnumStructAccessor(
                self.struct, EMCGET, MCGETI, None, ETIXQV, None, None, QBMJVH
            ),
            TIXQVX: GeckoEnumStructAccessor(
                self.struct, TIXQVX, IXQVXO, None, VXOIHB, None, None, QBMJVH
            ),
            XOIHBX: GeckoByteStructAccessor(self.struct, XOIHBX, OIHBXI, QBMJVH),
            IHBXIB: GeckoEnumStructAccessor(
                self.struct, IHBXIB, HBXIBH, None, BXIBHZ, None, None, QBMJVH
            ),
            XIBHZV: GeckoTimeStructAccessor(self.struct, XIBHZV, IBHZVO, QBMJVH),
            BHZVOA: GeckoTimeStructAccessor(self.struct, BHZVOA, HZVOAC, QBMJVH),
            ZVOACM: GeckoByteStructAccessor(self.struct, ZVOACM, VOACMC, QBMJVH),
            OACMCV: GeckoEnumStructAccessor(
                self.struct, OACMCV, ACMCVD, None, DSSRUR, None, None, QBMJVH
            ),
            SSRURA: GeckoTimeStructAccessor(self.struct, SSRURA, SRURAZ, QBMJVH),
            RURAZM: GeckoEnumStructAccessor(
                self.struct, RURAZM, QJYMOU, VDQLAI, AZMKQT, None, JYMOUN, QBMJVH
            ),
            ZMKQTD: GeckoEnumStructAccessor(
                self.struct, ZMKQTD, MKQTDK, None, TDKHTZ, None, None, QBMJVH
            ),
            DKHTZB: GeckoWordStructAccessor(self.struct, DKHTZB, KHTZBB, QBMJVH),
            HTZBBE: GeckoEnumStructAccessor(
                self.struct, HTZBBE, OUSPBW, BSIRYX, BBEKBD, None, JYMOUN, QBMJVH
            ),
            BEKBDF: GeckoBoolStructAccessor(
                self.struct, BEKBDF, OUSPBW, MOUNBL, QBMJVH
            ),
            EKBDFS: GeckoEnumStructAccessor(
                self.struct, EKBDFS, OUSPBW, SEMCGE, DFSROG, None, JYMOUN, QBMJVH
            ),
            FSROGM: GeckoBoolStructAccessor(
                self.struct, FSROGM, OUSPBW, SROGMD, QBMJVH
            ),
            ROGMDD: GeckoBoolStructAccessor(
                self.struct, ROGMDD, OUSPBW, OGMDDP, QBMJVH
            ),
            GMDDPM: GeckoBoolStructAccessor(
                self.struct, GMDDPM, MDDPMX, BWJYKL, QBMJVH
            ),
            DDPMXF: GeckoBoolStructAccessor(
                self.struct, DDPMXF, MDDPMX, BSIRYX, QBMJVH
            ),
            DPMXFU: GeckoEnumStructAccessor(
                self.struct, DPMXFU, MDDPMX, JYMOUN, XFUBJL, None, JYMOUN, QBMJVH
            ),
            FUBJLO: GeckoEnumStructAccessor(
                self.struct, FUBJLO, MDDPMX, VDQLAI, XFUBJL, None, JYMOUN, QBMJVH
            ),
            UBJLOI: GeckoEnumStructAccessor(
                self.struct, UBJLOI, MDDPMX, MOUNBL, LWUEUH, None, WUEUHN, QBMJVH
            ),
            UEUHNN: GeckoEnumStructAccessor(
                self.struct, UEUHNN, MDDPMX, OGMDDP, MNZMJI, None, JYMOUN, QBMJVH
            ),
            TGCRHY: GeckoBoolStructAccessor(
                self.struct, TGCRHY, GCRHYU, BSIRYX, QBMJVH
            ),
            CRHYUA: GeckoEnumStructAccessor(
                self.struct, CRHYUA, GCRHYU, JYMOUN, YUAXNC, None, MOUNBL, QBMJVH
            ),
            UAXNCU: GeckoBoolStructAccessor(
                self.struct, UAXNCU, GCRHYU, MOUNBL, QBMJVH
            ),
            AXNCUG: GeckoEnumStructAccessor(
                self.struct, AXNCUG, GCRHYU, SROGMD, CUGUCY, None, MOUNBL, QBMJVH
            ),
            UGUCYR: GeckoByteStructAccessor(self.struct, UGUCYR, GUCYRA, QBMJVH),
            UCYRAP: GeckoBoolStructAccessor(
                self.struct, UCYRAP, QJYMOU, BWJYKL, QBMJVH
            ),
            CYRAPU: GeckoByteStructAccessor(self.struct, CYRAPU, YRAPUM, QBMJVH),
            RAPUME: GeckoEnumStructAccessor(
                self.struct, RAPUME, APUMEA, None, EAOESV, None, None, QBMJVH
            ),
            AOESVZ: GeckoEnumStructAccessor(
                self.struct, AOESVZ, OESVZS, None, EAOESV, None, None, QBMJVH
            ),
            ESVZSS: GeckoEnumStructAccessor(
                self.struct, ESVZSS, SVZSSB, None, EAOESV, None, None, QBMJVH
            ),
            VZSSBV: GeckoEnumStructAccessor(
                self.struct, VZSSBV, ZSSBVN, None, EAOESV, None, None, QBMJVH
            ),
            SSBVNA: GeckoEnumStructAccessor(
                self.struct, SSBVNA, SBVNAX, None, EAOESV, None, None, QBMJVH
            ),
            BVNAXA: GeckoEnumStructAccessor(
                self.struct, BVNAXA, VNAXAD, None, XADXLU, None, None, QBMJVH
            ),
            ADXLUB: GeckoEnumStructAccessor(
                self.struct, ADXLUB, DXLUBG, None, UBGJFJ, None, None, QBMJVH
            ),
            BGJFJN: GeckoEnumStructAccessor(
                self.struct, BGJFJN, GJFJNT, BWJYKL, UVRFLS, None, WUEUHN, QBMJVH
            ),
            VRFLSI: GeckoBoolStructAccessor(
                self.struct, VRFLSI, GJFJNT, OGMDDP, QBMJVH
            ),
            RFLSIJ: GeckoEnumStructAccessor(
                self.struct, RFLSIJ, FLSIJU, None, EAOESV, None, None, QBMJVH
            ),
            LSIJUZ: GeckoByteStructAccessor(self.struct, LSIJUZ, SIJUZM, QBMJVH),
            IJUZMR: GeckoWordStructAccessor(self.struct, IJUZMR, JUZMRK, QBMJVH),
            UZMRKV: GeckoWordStructAccessor(self.struct, UZMRKV, ZMRKVF, QBMJVH),
            MRKVFC: GeckoWordStructAccessor(self.struct, MRKVFC, RKVFCP, QBMJVH),
            KVFCPO: GeckoWordStructAccessor(self.struct, KVFCPO, VFCPOU, QBMJVH),
            FCPOUB: GeckoWordStructAccessor(self.struct, FCPOUB, CPOUBM, QBMJVH),
            POUBMI: GeckoWordStructAccessor(self.struct, POUBMI, OUBMIK, QBMJVH),
            UBMIKG: GeckoWordStructAccessor(self.struct, UBMIKG, BMIKGN, QBMJVH),
            MIKGNV: GeckoWordStructAccessor(self.struct, MIKGNV, IKGNVF, QBMJVH),
            KGNVFO: GeckoWordStructAccessor(self.struct, KGNVFO, GNVFOU, QBMJVH),
            NVFOUU: GeckoWordStructAccessor(self.struct, NVFOUU, VFOUUR, QBMJVH),
            FOUURI: GeckoEnumStructAccessor(
                self.struct, FOUURI, OUURIE, BWJYKL, URIEVB, None, JYMOUN, None
            ),
            RIEVBV: GeckoEnumStructAccessor(
                self.struct, RIEVBV, OUURIE, BSIRYX, VBVHDV, None, JYMOUN, None
            ),
            BVHDVR: GeckoEnumStructAccessor(
                self.struct, BVHDVR, VHDVRI, BWJYKL, URIEVB, None, JYMOUN, None
            ),
            HDVRID: GeckoEnumStructAccessor(
                self.struct, HDVRID, VHDVRI, BSIRYX, VBVHDV, None, JYMOUN, None
            ),
            DVRIDK: GeckoEnumStructAccessor(
                self.struct, DVRIDK, VRIDKE, BWJYKL, URIEVB, None, JYMOUN, None
            ),
            RIDKEY: GeckoEnumStructAccessor(
                self.struct, RIDKEY, VRIDKE, BSIRYX, VBVHDV, None, JYMOUN, None
            ),
            IDKEYG: GeckoEnumStructAccessor(
                self.struct, IDKEYG, DKEYGG, BWJYKL, URIEVB, None, JYMOUN, None
            ),
            KEYGGV: GeckoEnumStructAccessor(
                self.struct, KEYGGV, DKEYGG, BSIRYX, VBVHDV, None, JYMOUN, None
            ),
            EYGGVY: GeckoEnumStructAccessor(
                self.struct, EYGGVY, YGGVYK, BWJYKL, KLTQLV, None, WUEUHN, None
            ),
            LTQLVH: GeckoEnumStructAccessor(
                self.struct, LTQLVH, YGGVYK, VDQLAI, LVHSVS, None, WUEUHN, QBMJVH
            ),
            VHSVSI: GeckoBoolStructAccessor(self.struct, VHSVSI, YGGVYK, OGMDDP, None),
            HSVSIB: GeckoBoolStructAccessor(self.struct, HSVSIB, OUURIE, MOUNBL, None),
            SVSIBE: GeckoBoolStructAccessor(self.struct, SVSIBE, OUURIE, SEMCGE, None),
            VSIBEX: GeckoBoolStructAccessor(self.struct, VSIBEX, OUURIE, SROGMD, None),
            SIBEXL: GeckoBoolStructAccessor(self.struct, SIBEXL, OUURIE, OGMDDP, None),
            IBEXLT: GeckoBoolStructAccessor(self.struct, IBEXLT, VHDVRI, MOUNBL, None),
            BEXLTP: GeckoBoolStructAccessor(self.struct, BEXLTP, VHDVRI, SEMCGE, None),
            EXLTPO: GeckoBoolStructAccessor(self.struct, EXLTPO, VHDVRI, SROGMD, None),
            XLTPOX: GeckoBoolStructAccessor(self.struct, XLTPOX, VHDVRI, OGMDDP, None),
            LTPOXI: GeckoBoolStructAccessor(self.struct, LTPOXI, VRIDKE, MOUNBL, None),
            TPOXIU: GeckoBoolStructAccessor(self.struct, TPOXIU, VRIDKE, SEMCGE, None),
            POXIUV: GeckoBoolStructAccessor(self.struct, POXIUV, VRIDKE, SROGMD, None),
            OXIUVM: GeckoBoolStructAccessor(self.struct, OXIUVM, VRIDKE, OGMDDP, None),
            XIUVMK: GeckoBoolStructAccessor(self.struct, XIUVMK, DKEYGG, MOUNBL, None),
            IUVMKZ: GeckoBoolStructAccessor(self.struct, IUVMKZ, DKEYGG, SEMCGE, None),
            UVMKZH: GeckoBoolStructAccessor(self.struct, UVMKZH, DKEYGG, SROGMD, None),
            VMKZHW: GeckoBoolStructAccessor(self.struct, VMKZHW, DKEYGG, OGMDDP, None),
            MKZHWO: GeckoEnumStructAccessor(
                self.struct, MKZHWO, KZHWOG, None, XXYOJQ, None, None, None
            ),
            XYOJQS: GeckoEnumStructAccessor(
                self.struct, XYOJQS, YOJQSG, MOUNBL, JQSGME, None, WUEUHN, QBMJVH
            ),
            QSGMEC: GeckoBoolStructAccessor(self.struct, QSGMEC, YOJQSG, OGMDDP, None),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'MAS-IBC-32K v1'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
AHEOCT = 8
AKQXPI = "".join(chr(c) for c in [66, 65, 83, 73, 67])
ASSAKQ = "".join(chr(c) for c in [76, 76, 95, 67, 104, 114, 111, 109, 111])
BMJVHF = "".join(chr(c) for c in [68, 85, 65, 76])
CQBMJV = 0
CTHBSK = 1
CVYYPI = "".join(chr(c) for c in [73, 110, 116, 101, 110, 115, 105, 116, 121, 52])
ECVYYP = "".join(chr(c) for c in [73, 110, 116, 101, 110, 115, 105, 116, 121, 51])
EOCTHB = "".join(chr(c) for c in [76, 73])
FTHECV = 1
FXQGLR = "".join(
    chr(c) for c in [76, 76, 95, 67, 111, 109, 102, 111, 114, 116, 74, 101, 116]
)
GLRAHE = "".join(chr(c) for c in [65, 67, 84, 73, 86, 65, 84, 69])
HECVYY = "".join(chr(c) for c in [73, 110, 116, 101, 110, 115, 105, 116, 121, 50])
HFTHEC = "".join(chr(c) for c in [76, 76, 95, 72, 101, 97, 116, 101, 114, 95, 49])
ICXQIE = "".join(chr(c) for c in [77, 80, 51])
IEFXQG = "".join(chr(c) for c in [72, 79, 84, 69, 76])
IPIVLA = 3
IVLASS = "".join(chr(c) for c in [72, 73, 71, 72])
JVHFTH = "".join(
    chr(c) for c in [68, 85, 65, 76, 95, 76, 73, 84, 69, 83, 84, 82, 69, 77, 69]
)
KQXPIC = "".join(chr(c) for c in [68, 69, 76, 85, 88, 69])
MJVHFT = "".join(
    chr(c) for c in [68, 85, 65, 76, 95, 84, 72, 69, 82, 77, 79, 80, 76, 65, 67, 69]
)
PICXQI = 5
PIPIVL = "".join(chr(c) for c in [76, 76, 95, 66, 108, 111, 119, 101, 114])
PIVLAS = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
QBMJVH = "".join(chr(c) for c in [83, 73, 78, 71, 76, 69])
QGLRAH = "".join(chr(c) for c in [68, 69, 65, 67, 84, 73, 86, 65, 84, 69])
QIEFXQ = 6
RAHEOC = "".join(
    chr(c) for c in [76, 76, 95, 65, 114, 111, 109, 97, 99, 108, 111, 117, 100]
)
SAKQXP = "".join(chr(c) for c in [78, 79, 78, 69])
SSAKQX = 4
THECVY = "".join(chr(c) for c in [73, 110, 116, 101, 110, 115, 105, 116, 121, 49])
VLASSA = "".join(chr(c) for c in [76, 79, 87])
XPICXQ = "".join(chr(c) for c in [76, 76, 95, 65, 117, 100, 105, 111])
XQGLRA = 7
XQIEFX = "".join(chr(c) for c in [76, 76, 95, 77, 101, 110, 117])
YPIPIV = 2
YYPIPI = "".join(chr(c) for c in [76, 76, 95, 72, 101, 97, 116, 101, 114, 95, 50])
ZCQBMJ = "".join(chr(c) for c in [76, 76, 95, 66, 97, 99, 107, 114, 101, 115, 116])
CXQIEF = [SAKQXP, ICXQIE]
EFXQGL = [PIVLAS, IEFXQG]
HEOCTH = []
LASSAK = [PIVLAS, IVLASS, VLASSA]
LRAHEO = [QGLRAH, GLRAHE]
OCTHBS = [EOCTHB]
QXPICX = [SAKQXP, AKQXPI, KQXPIC]
VHFTHE = [QBMJVH, BMJVHF, MJVHFT, JVHFTH]
VYYPIP = [THECVY, HECVYY, ECVYYP, CVYYPI]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return CTHBSK

    @property
    def output_keys(self):
        return HEOCTH

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoEnumStructAccessor(
                self.struct, ZCQBMJ, CQBMJV, None, VHFTHE, None, None, None
            ),
            HFTHEC: GeckoEnumStructAccessor(
                self.struct, HFTHEC, FTHECV, None, VYYPIP, None, None, None
            ),
            YYPIPI: GeckoEnumStructAccessor(
                self.struct, YYPIPI, YPIPIV, None, VYYPIP, None, None, None
            ),
            PIPIVL: GeckoEnumStructAccessor(
                self.struct, PIPIVL, IPIVLA, None, LASSAK, None, None, None
            ),
            ASSAKQ: GeckoEnumStructAccessor(
                self.struct, ASSAKQ, SSAKQX, None, QXPICX, None, None, None
            ),
            XPICXQ: GeckoEnumStructAccessor(
                self.struct, XPICXQ, PICXQI, None, CXQIEF, None, None, None
            ),
            XQIEFX: GeckoEnumStructAccessor(
                self.struct, XQIEFX, QIEFXQ, None, EFXQGL, None, None, None
            ),
            FXQGLR: GeckoEnumStructAccessor(
                self.struct, FXQGLR, XQGLRA, None, LRAHEO, None, None, None
            ),
            RAHEOC: GeckoEnumStructAccessor(
                self.struct, RAHEOC, AHEOCT, None, LRAHEO, None, None, None
            ),
        }



"""A peekable async queue"""

import asyncio.queues
from typing import Any


class AsyncPeekableQueue(asyncio.queues.Queue):
    """A peekable async queue which allows queue filtering in consumers"""

    def __init__(self):
        super().__init__()
        self._marked = False

    @property
    def head(self) -> Any:
        """The head property will reveal the item at the head of the queue
        if there is one, or None if there isn't one"""
        if self.qsize() > 0:
            return self._queue[0]  # type: ignore
        return None

    @property
    def is_marked(self) -> bool:
        return self._marked

    def pop(self) -> Any:
        self.get_nowait()
        self._marked = False

    def mark(self) -> None:
        self._marked = True



""" Gecko CURCH/CHCUR handlers """

import logging
import struct

from .packet import GeckoPacketProtocolHandler

CURCH_VERB = b"CURCH"
CHCUR_VERB = b"CHCUR"
GETCHANNEL_FORMAT = ">BB"

_LOGGER = logging.getLogger(__name__)


class GeckoGetChannelProtocolHandler(GeckoPacketProtocolHandler):
    @staticmethod
    def request(seq, **kwargs):
        return GeckoGetChannelProtocolHandler(
            content=b"".join([CURCH_VERB, struct.pack(">B", seq)]),
            timeout=2,
            retry_count=10,
            on_retry_failed=GeckoPacketProtocolHandler._default_retry_failed_handler,
            **kwargs,
        )

    @staticmethod
    def response(channel, signal_strength, **kwargs):
        return GeckoGetChannelProtocolHandler(
            content=b"".join(
                [
                    CHCUR_VERB,
                    struct.pack(
                        GETCHANNEL_FORMAT,
                        channel,
                        signal_strength,
                    ),
                ]
            ),
            **kwargs,
        )

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.channel = self.signal_strength = None

    def can_handle(self, received_bytes: bytes, sender: tuple) -> bool:
        return received_bytes.startswith(CURCH_VERB) or received_bytes.startswith(
            CHCUR_VERB
        )

    def handle(self, received_bytes: bytes, sender: tuple) -> None:
        remainder = received_bytes[5:]
        if received_bytes.startswith(CURCH_VERB):
            self._sequence = struct.unpack(">B", remainder)[0]
            return  # Stay in the handler list
        # Otherwise must be CHCUR
        (
            self.channel,
            self.signal_strength,
        ) = struct.unpack(GETCHANNEL_FORMAT, remainder)
        self._should_remove_handler = True
